**delete** - Delete a profile
===============================

Usage
------

.. code::

    e4s-cl profile delete <NAME>

Description
-------------

.. automodule:: e4s_cl.cli.commands.profile.delete
